@@ -1,5 +1,6 @@
 import os
 import json
+import logging
 from functools import partial
 
 import dash
@@ -16,6 +17,7 @@ from dash._utils import (
     format_tag
 )
 from .utilities import is_authenticated
+logger = logging.getLogger(__name__)
 BASE_API_URL = os.getenv('DATA_API_BASE_URL', '')
 
 _app_entry = """
@@ -113,12 +115,18 @@ class OAPDash(dash.Dash):
 
 
     def index(self, *args, **kwargs):  # pylint: disable=unused-argument
+        logger.info("verifying authentication")
+        print("verifying authentication")
         if is_authenticated():
+            logger.info("authentication is successful")
+            print("authentication is successful")
             resp = self._index(args, kwargs)
             return resp
         else:
             # return flask.Response('Not authorized', status=401)
             redirect_url = BASE_API_URL + f'/tenancy/web/login?cb=/loginResponse.do'
+            logger.info("authentication is failed, redirecting to login url is %s", redirect_url)
+            print("authentication is failed, redirecting to login url is ", redirect_url)
             return flask.redirect(redirect_url, code=302)
 
 
