@@ -28,7 +28,8 @@ from analytics_sdk.utilities import (
     API_KEY,
     API_SECRET,
     API_RETRY,
-    API_TIME_STACKS
+    API_TIME_STACKS,
+    APP_DISPLAY_NAME
     )
 
 #app_name = os.getenv("PLATFORM_ROUTE")
@@ -354,6 +355,38 @@ class ExcelRenderer:
             return names, client_id
 
 
+    def generate_glossary(self, ws, sheet_resp, title):
+        """
+        add glossary sheet
+        """
+        for row_idx in range(1, 30):
+            row = ws.row_dimensions[row_idx]
+            row.fill = PatternFill("solid", fgColor="eeeeee")
+
+        ws.column_dimensions['B'].width = 50
+        ws.column_dimensions['C'].width = 24
+
+        header_idx = 2
+        value_idx = 2
+        if sheet_resp is not None and 'data' in sheet_resp and sheet_resp['data'] is not None:
+            data = sheet_resp['data']
+            for key in data.keys():
+                header_idx += 1
+                value_idx += 1
+                display_name = key
+                display_value = data[key]
+
+                cell = ws[f'B{header_idx}']
+                cell.value = display_name
+                cell.font = Font(color="00598B")
+                cell.fill = PatternFill("solid", fgColor="eeeeee")
+
+                cell = ws[f'C{value_idx}']
+                cell.value = display_value
+                cell.font = Font(color="000000")
+                cell.fill = PatternFill("solid", fgColor="eeeeee")
+
+
     def generate_summary(self, res, tenantId, additional_props, report_gen_start_time, report_gen_completed_time):
         """
         add summary sheet
@@ -387,7 +420,7 @@ class ExcelRenderer:
         cell.fill = PatternFill("solid", fgColor="eeeeee")
 
         cell = ws['C4']
-        cell.value = APP_ID.replace('-', ' ').title()
+        cell.value = APP_DISPLAY_NAME.replace('-', ' ').title()
         cell.font = Font(color="000000")
         cell.fill = PatternFill("solid", fgColor="eeeeee")
 
@@ -402,43 +435,43 @@ class ExcelRenderer:
         cell.font = Font(color="000000")
         cell.fill = PatternFill("solid", fgColor="eeeeee")
 
+        #cell = ws['B6']
+        #cell.value = 'Tenant Id'
+        #cell.font = Font(color="00598B")
+        #cell.fill = PatternFill("solid", fgColor="eeeeee")
+
+        #cell = ws['C6']
+        ## cell.value = tenantId
+        #cell.value = c_id
+        #cell.font = Font(color="000000")
+        #cell.fill = PatternFill("solid", fgColor="eeeeee")
+
         cell = ws['B6']
-        cell.value = 'Tenant Id'
-        cell.font = Font(color="00598B")
-        cell.fill = PatternFill("solid", fgColor="eeeeee")
-
-        cell = ws['C6']
-        # cell.value = tenantId
-        cell.value = c_id
-        cell.font = Font(color="000000")
-        cell.fill = PatternFill("solid", fgColor="eeeeee")
-
-        cell = ws['B7']
         cell.value = 'Run date'
         cell.font = Font(color="00598B")
         cell.fill = PatternFill("solid", fgColor="eeeeee")
 
-        cell = ws['C7']
+        cell = ws['C6']
         cell.value = report_gen_start_time
         cell.font = Font(color="000000")
         cell.fill = PatternFill("solid", fgColor="eeeeee")
 
-        cell = ws['B8']
+        cell = ws['B7']
         cell.value = 'Completion date'
         cell.font = Font(color="00598B")
         cell.fill = PatternFill("solid", fgColor="eeeeee")
 
-        cell = ws['C8']
+        cell = ws['C7']
         cell.value = report_gen_completed_time
         cell.font = Font(color="000000")
         cell.fill = PatternFill("solid", fgColor="eeeeee")
 
-        cell = ws['B9']
+        cell = ws['B8']
         cell.value = 'User'
         cell.font = Font(color="00598B")
         cell.fill = PatternFill("solid", fgColor="eeeeee")
 
-        cell = ws['C9']
+        cell = ws['C8']
         first_name = res.json()['analysisRun']['createdBy']['firstName']
         last_name = res.json()['analysisRun']['createdBy']['lastName']
         login_name = res.json()['analysisRun']['createdBy']['loginName']
@@ -446,8 +479,8 @@ class ExcelRenderer:
         cell.font = Font(color="000000")
         cell.fill = PatternFill("solid", fgColor="eeeeee")
 
-        header_idx = 9
-        value_idx = 9
+        header_idx = 8
+        value_idx = 8
         if opsql_params is not None:
 
             for key in opsql_params.keys():
@@ -574,10 +607,14 @@ class ExcelRenderer:
         # run_data = self.analysis_run
         run_data = self.excel_data
         for sheet in run_data['sheets']:
-            ws = self.wb.create_sheet(title=sheet['title'])
-            self.add_header(ws, sheet)
+            if 'documentation' in sheet and sheet['documentation'] == 'true':
+                ws = self.wb.create_sheet(title=sheet['title'])
+                self.generate_glossary(ws, sheet, title=sheet['title'])
+            else:
+                ws = self.wb.create_sheet(title=sheet['title'])
+                self.add_header(ws, sheet)
 
-            for component_data in sheet['components']:
-                self.add_component(ws, component_data)
+                for component_data in sheet['components']:
+                    self.add_component(ws, component_data)
 
         return self.wb
