@@ -31,6 +31,7 @@ BASE_API_URL = os.getenv('DATA_API_BASE_URL', '')
 PLATFORM_ROUTE = os.getenv("PLATFORM_ROUTE")
 APP_ID = os.getenv('APP_ID')
 API_TIME_STACKS = int(os.getenv('API_TIME_STACKS', 5))
+APP_DISPLAY_NAME = os.getenv('APP_DISPLAY_NAME', APP_ID)
 
 from .renderer.excel import ExcelRenderer
 from .renderer.pdf import PDF
@@ -102,7 +103,7 @@ def get_auth_token():
     json = response.json()
     auth = str(json["token_type"]) + " " + str(json["access_token"])
     global ACCESS_HEADER
-    ACCESS_HEADER = {"Content-Type" : "application/json" ,"Accept" : "application/json" , "Authorization" : auth }
+    ACCESS_HEADER = {"Content-Type" : "application/json" ,"Accept" : "application/json" , "Authorization" : auth}
 
 
 def call_requests(method, url, params=None, data=None, json=None, verify=True):
@@ -145,19 +146,27 @@ def login_call_requests(method, url, params=None, data=None, json=None, verify=T
     retry = 1
     resp = None
     while retry <= API_RETRY:
+        logger.info(f"Processing authentication request at {retry} iteration ")
+        print(f"Processing authentication request at {retry} iteration ")
         try:
             resp = requests.request(method, url, params=params, data=data, json=json, headers=headers, verify=verify)
+            logger.info("authentication response is %s %s", resp,url)
+            print("authentication response is ", resp, url)
             if not resp.ok:
                 time.sleep(retry * 2)
                 retry+=1
+                logger.info(f"Invalid response, going to {retry} iteration ")
+                print(f"Invalid response, going to {retry} iteration ")
                 continue
         except requests.exceptions.ConnectionError:
             time.sleep(retry * 2)
             retry+=1
+            logger.info(f"Got the exception, going to {retry} iteration ")
+            print(f"Got the exception, going to {retry} iteration ")
             continue
-
+        logger.info("Response is %s  ", resp)
+        print("Response is ", resp)
         return resp
-
     return resp
 
 
@@ -179,14 +188,21 @@ def login_call_get_requests(url, params=None, verify=True):
 
 def is_authenticated():
     REQUIRE_AUTH_REDIRECT = os.getenv('REQUIRE_AUTH_REDIRECT') == 'true'
+    logger.info("Getting authentication configuration value %s", REQUIRE_AUTH_REDIRECT)
+    print("Getting authentication configuration value ", REQUIRE_AUTH_REDIRECT)
     if not REQUIRE_AUTH_REDIRECT:
+        logger.info("authentication is not verifying,means bypassing authentication")
+        print("authentication is not verifying,means bypassing authentication")
         return True
-
+    
     url = f'{BASE_API_URL}/api/v2/users/me'
+    logger.info("authentication is verifying, request URL is %s",url)
+    print("authentication is verifying, request URL is ",url)
     res = login_call_get_requests(url)
     return res.status_code == 200
 
 
+
 def login_required(view):
     '''Decorator that check authentication'''
   
@@ -349,35 +365,40 @@ def upload_to_storage(content, location):
 
 
 def generate_pdf(analysis_run):
-    logger.info('Entered into pdf generation process')
+    logger.info(f'{analysis_run} :: Entered into pdf generation process')
     try:
         url = os.getenv("PDF_SERVICE")
         current_date = datetime.now()
-        file_name = APP_ID.lower() + '-' + analysis_run[:8] + '-' + current_date.strftime("%Y-%m-%d-%H-%M-%S") + '.pdf'
+        # file_name = APP_ID.lower() + '-' + pdf.analysis_run[:8] + '-' + current_date.strftime("%Y-%m-%d-%H-%M-%S") + '.pdf'
         report_path = ''
         if storage_name == 's3':
             report_path = PLATFORM_ROUTE
         elif storage_name == 'ceph':
             report_path = APP_ID.lower()
+        pdf = PDF(analysis_run, url, report_path, current_date.strftime("%Y-%m-%d-%H-%M-%S"))
+        file_name = pdf.prepare_file_name(APP_ID.lower(), 'pdf')
+        file_path = pdf.report_path + '/' + pdf.analysis_run + '/pdf/' + file_name
         data = {
             'domain': BASE_API_URL,
             'report': PLATFORM_ROUTE,
-            'run': analysis_run,
+            'run': pdf.analysis_run,
             'route': '/full-view',
             'token': get_token(),
             'app_id': APP_ID,
             'size': 'A4',
             'storage': storage_name,
-            'file_name': file_name
+            'file_name': file_name,
+            'file_path': file_path
         }
-        pdf = PDF(analysis_run, url, file_name, report_path, data)
+        
         gen_retry = 1
         while gen_retry <= 2:
             logging.info(f'{pdf.analysis_run} :: pdf generation trying {gen_retry} time..')
             gen_retry += 1
-            response = pdf.generate()
+            logging.info(f'b4 generation >> full file path : {file_path}')
+            response = pdf.generate(data)
+            logging.info(f'after generation >> full file path : {file_path}')
             if response == 504:
-                file_path = pdf.report_path + '/' + pdf.analysis_run + '/pdf/' + pdf.file_name
                 storage_retry = 1
                 file_found = False
                 while storage_retry <= API_RETRY:
@@ -396,7 +417,8 @@ def generate_pdf(analysis_run):
         raise Exception(f'Generate_pdf:: pdf generation failed after max tries ({API_RETRY}), for run ::: {pdf.analysis_run}')
     except Exception as e:
         traceback.print_exc()
-        raise Exception(f'Generate_pdf:: Exec - pdf generation failed after max tries({API_RETRY}), for run ::: {analysis_run}')
+        err_msg = f'Generate_pdf:: Exeception - pdf generation failed after max tries({API_RETRY}), for run ::: {analysis_run}'
+        raise Exception(err_msg)
 
 
 def is_file_in_storage(file_path: str):
@@ -582,6 +604,35 @@ def init_mail(org_id, run_id):
     logger.info('finished init_mail method')
 
 
+
+def send_internal_failure_notification_mail(run_id, app_name, err_msg, partner_id, partner_name, client_id, client_name):
+    logger.info('Entered into send_internal_failure_notification_mail method')
+    try:
+        url = BASE_API_URL + f'/reporting/api/v3/sendInternalFailureNotifications'
+        data = {
+            "runId": run_id,
+            "appName": app_name,
+            "exception": err_msg,
+            "partnerId": partner_id,
+            "partnerName": partner_name,
+            "clientIds": client_id,
+            "clientNames": client_name
+        }
+        t1 = int(time.time())
+        res = call_post_requests(url , data=json.dumps(data), verify=False)
+        t2 = int(time.time())
+        duration = t2-t1
+        if duration > API_TIME_STACKS:
+            logging.info('Send internal failure notification mail response took %d (greater than %d) seconds', duration, API_TIME_STACKS)
+        logger.info('Send internal failure notification mail response is %s', res)
+    except Exception as e:
+        raise e
+        logger.error("Exception raised due to : " + repr(e))
+        traceback.print_exc()
+    logger.info('finished send_internal_failure_notification_mail method')
+
+
+
 def upload_excel(analysis_run, excel_file):
     timestamp = datetime.now().strftime("%Y-%m-%d-%H-%M-%S")
     s3_path = f'{analysis_run.analysis.app.slug}/excel/{timestamp}.xlsx'
@@ -760,7 +811,7 @@ def prepare_tenant_list(form, parameters, all_clients=False):
             tenant_id_list = fetch_all_clients(form.get_tenant_id(), form.get_tenant_context(), all_clients)
         elif 'client' in parameters and parameters['client'] is not None:
             clients = parameters['client']
-            if clients == 'All Clients' or clients == 'All Client':
+            if clients == 'All Clients' or clients == 'All Client' or clients == ['All Clients']:
                 tenant_id_list = fetch_all_clients(form.get_tenant_id(), form.get_tenant_context(), all_clients)
             else:
                 if isinstance(clients, list):
@@ -825,21 +876,30 @@ def get_app_logo(id, context, parameters):
                 return get_logo_path_url(id)
             elif 'client' in parameters and parameters['client'] is not None:
                 clients = parameters['client']
-                if isinstance(clients, list):
-                    if len(clients) == 1:
-                        for cid in clients:
-                            return get_logo_path_url(cid)
-                    else:
-                        return get_logo_path_url(id)
+                if clients == 'All Clients' or clients == 'All Client' or clients == ['All Clients']:
+                    return get_logo_path_url(id)
                 else:
-                    return get_logo_path_url(clients) 
+                    if isinstance(clients, list):
+                        if len(clients) == 1:
+                            for cid in clients:
+                                return get_logo_path_url(cid)
+                        else:
+                            return get_logo_path_url(id)
+                    else:
+                        return get_logo_path_url(clients) 
     return get_logo_path_url(id)
 
 
 def update_run_progress(tenant_id, run_id, percent, message):
-    url = BASE_API_URL + f'/reporting/api/v3/tenants/{tenant_id}/runs/{run_id}'
+    url = BASE_API_URL + f'/reporting/api/v3/tenants/{tenant_id}/runs/{run_id}/progress'
     data = {
-        "percent" : percent,
-        "message" : message
+        "runningPercentage" : percent
     }
+    res = call_put_requests(url , data=json.dumps(data), verify=False);
+    if res == None or not res.ok:
+        logger.error('Update run progress API is failed')
+        return res
+    else:
+        logger.error('Update run progress result updated upto %d',  percent)
+        return res
     #TODO : Implement logic here to update the run
\ No newline at end of file
